@@ -2,13 +2,14 @@
 #define NOTIFYGVINBOX_H
 
 #include "global.h"
+#include "GVApi.h"
 
 class GVInbox : public QObject
 {
     Q_OBJECT
 
 public:
-    GVInbox (QObject *parent = 0);
+    GVInbox (GVApi &gref, QObject *parent = 0);
     ~GVInbox(void);
 
 signals:
@@ -25,17 +26,23 @@ public slots:
 
 private slots:
     void oneInboxEntry (const GVInboxEntry &hevent);
-    void getInboxDone (bool bOk, const QVariantList &arrParams);
+    void getInboxDone (AsyncTaskToken *token);
 
 private:
+    GVApi          &gvApi;
+
     //! Mutex for the following variables
     QMutex          mutex;
 
     //! Are we logged in?
     bool            bLoggedIn;
 
+    //! Is there a refresh in progress?
+    bool            bRefreshInProgress;
+
     //! Date time of latest update
-    QDateTime       dtUpdate;
+    QDateTime       dtLatest;
+    QDateTime       dtPrevLatest;
 };
 
 #endif // NOTIFYGVINBOX_H
