@@ -290,8 +290,6 @@ CacheDatabase::putUserPass (const QString &strUser, const QString &strPass)
     QByteArray byD;
     OsDependent &osd = Singletons::getRef().getOSD ();
     QString strQ;
-    QSqlQuery query(dbMain);
-    query.setForwardOnly (true);
 
     osd.cipher (strUser.toAscii (), byD, true);
     settings->setValue (GV_S_VAR_USER, QString (byD.toHex ()));
@@ -309,6 +307,61 @@ CacheDatabase::clearUserPass ()
     settings->remove (GV_S_VAR_PASS);
 }//CacheDatabase::clearUserPass
 
+bool
+CacheDatabase::getContactsPass(QString &strPass)
+{
+    QByteArray byD;
+    OsDependent &osd = Singletons::getRef().getOSD ();
+    QString strResult;
+
+    if (settings->contains (GV_S_VAR_CPASS)) {
+        strResult = settings->value(GV_S_VAR_CPASS).toString();
+        osd.cipher (QByteArray::fromHex (strResult.toAscii ()), byD, false);
+        strPass = byD;
+
+        return (true);
+    }
+
+    return (false);
+}//CacheDatabase::getContactsPass
+
+bool
+CacheDatabase::setContactsPass(const QString &strPass)
+{
+    QByteArray byD;
+    OsDependent &osd = Singletons::getRef().getOSD ();
+    QString strQ;
+
+    osd.cipher (strPass.toAscii (), byD, true);
+    settings->setValue (GV_S_VAR_CPASS, QString (byD.toHex ()));
+
+    return (true);
+}//CacheDatabase::setContactsPass
+
+void
+CacheDatabase::clearContactsPass()
+{
+    settings->remove (GV_S_VAR_CPASS);
+}//CacheDatabase::clearContactsPass
+
+void
+CacheDatabase::setTFAFlag(bool set)
+{
+    settings->setValue (GV_S_VAR_TFA, set);
+}//CacheDatabase::setTFAFlag
+
+bool
+CacheDatabase::getTFAFlag()
+{
+    return (settings->value(GV_S_VAR_TFA).toBool());
+}//CacheDatabase::getTFAFlag
+
+void
+CacheDatabase::clearTFAFlag()
+{
+    settings->remove (GV_S_VAR_TFA);
+}//CacheDatabase::clearTFAFlag
+
 bool
 CacheDatabase::getCallback (QString &strCallback)
 {
@@ -443,31 +496,22 @@ CacheDatabase::insertContact (const ContactInfo &info)
                         .arg (scrubInfo.dtUpdate.toTime_t());
         rv = query.exec (strQ);
         if (!rv) {
-            qWarning () << "Failed to insert row into contacts table. ID:["
-                        << info.strId
-                        << "] name=["
-                        << info.strTitle
-                        << "]";
+            Q_WARN(QString("Failed to insert row into contacts table. "
+                           "ID:[%1] name=[%2]").arg(info.strId, info.strTitle));
             break;
         }
 
         rv = putContactInfo (info);
         if (!rv) {
-            qWarning () << "Failed to insert contact info into contacts table. ID:["
-                        << info.strId
-                        << "] name=["
-                        << info.strTitle
-                        << "]";
+            Q_WARN(QString("Failed to insert contact info into contacts table. "
+                           "ID:[%1] name=[%2]").arg(info.strId, info.strTitle));
             break;
         }
 
         rv = putTempFile (info.hrefPhoto, info.strPhotoPath);
         if (!rv) {
-            qWarning () << "Failed to insert photo into contacts table. ID:["
-                        << info.strId
-                        << "] name=["
-                        << info.strTitle
-                        << "]";
+            Q_WARN(QString("Failed to insert photo into contacts table. "
+                           "ID:[%1] name=[%2]").arg(info.strId, info.strTitle));
             break;
         }
 
@@ -555,7 +599,7 @@ bool
 CacheDatabase::getContactFromLink (ContactInfo &info)
 {
     if (!existsContact (info.strId)) {
-        qWarning() << "Contact with ID" << info.strId << "is not cached.";
+        Q_WARN(QString("Contact with ID %1 is not cached.").arg(info.strId));
         return false;
     }
 
@@ -575,8 +619,7 @@ CacheDatabase::getContactFromLink (ContactInfo &info)
            .arg (scrubId);
     query.exec (strQ);
     if (!query.next ()) {
-        qWarning("Contact not found!!! "
-                 "I thought we confirmed this at the top of the function!!");
+        Q_CRIT("Contact not found!!!");
         return false;
     }
     info.strTitle  = query.value(0).toString ();
@@ -655,7 +698,7 @@ CacheDatabase::getLatestContact (QDateTime &dateTime)
                 "ORDER BY " GV_C_UPDATED " DESC");
     do { // Begin cleanup block (not a loop)
         if (!query.next ()) {
-            qWarning ("Couldn't get the latest contact");
+            Q_WARN("Couldn't get the latest contact");
             break;
         }
 
@@ -663,7 +706,7 @@ CacheDatabase::getLatestContact (QDateTime &dateTime)
         bool bOk = false;
         quint64 dtVal = query.value(0).toULongLong (&bOk);
         if (!bOk) {
-            qWarning ("Could not convert datetime for latest contact");
+            Q_WARN("Could not convert datetime for latest contact");
             break;
         }
 
@@ -756,7 +799,7 @@ CacheDatabase::getLatestInboxEntry (QDateTime &dateTime)
     {
         if (!query.next ())
         {
-            qWarning ("Couldn't get the latest inbox item");
+            Q_WARN("Couldn't get the latest inbox item");
             break;
         }
 
@@ -765,7 +808,7 @@ CacheDatabase::getLatestInboxEntry (QDateTime &dateTime)
         quint64 dtVal = query.value(0).toULongLong (&bOk);
         if (!bOk)
         {
-            qWarning ("Could not convert datetime for latest inbox update");
+            Q_WARN("Could not convert datetime for latest inbox update");
             break;
         }
 
@@ -810,7 +853,7 @@ CacheDatabase::insertInboxEntry (const GVInboxEntry &hEvent)
     scrubEvent.strNote.replace ("'", "''");
 
     if (scrubEvent.strText.contains ("Enter a new or existing contact name")) {
-        qWarning ("WHAA");
+        Q_CRIT("WHAA");
     }
 
     QSqlQuery query(dbMain);
@@ -844,7 +887,7 @@ CacheDatabase::insertInboxEntry (const GVInboxEntry &hEvent)
                             .arg (scrubEvent.strText)
                             .arg (scrubEvent.strNote));
         if (!rv) {
-            qWarning ("Failed to insert row into inbox table");
+            Q_WARN("Failed to insert row into inbox table");
             break;
         }
 
@@ -854,6 +897,23 @@ CacheDatabase::insertInboxEntry (const GVInboxEntry &hEvent)
     return (rv);
 }//CacheDatabase::insertInboxEntry
 
+bool
+CacheDatabase::deleteInboxEntryById (const QString &id)
+{
+    QString scrubId = id;
+    scrubId.replace ("'", "''");
+
+    QSqlQuery query(dbMain);
+    query.setForwardOnly (true);
+
+    bool rv =
+    query.exec (QString ("DELETE FROM " GV_INBOX_TABLE " "
+                         "WHERE " GV_IN_ID "='%1'")
+                .arg (scrubId));
+
+    return (rv);
+}//CacheDatabase::deleteInboxEntryById
+
 bool
 CacheDatabase::markAsRead (const QString &msgId)
 {
@@ -869,13 +929,13 @@ CacheDatabase::markAsRead (const QString &msgId)
                                  " WHERE " GV_IN_ID "='%1'").arg (scrubId));
         if (!rv || !query.next ()) {
             rv = false;
-            qWarning ("Failed to get the inbox entry to mark as read");
+            Q_WARN("Failed to get the inbox entry to mark as read");
             break;
         }
 
         quint32 flags = query.value (0).toInt (&rv);
         if (!rv) {
-            qWarning ("Failed to convert flags result into integer");
+            Q_WARN("Failed to convert flags result into integer");
             break;
         }
 
@@ -892,7 +952,7 @@ CacheDatabase::markAsRead (const QString &msgId)
                                  "WHERE " GV_IN_ID "='%2'")
                          .arg(flags).arg (scrubId));
         if (!rv) {
-            qWarning ("Failed to update inbox table with a flag marked read");
+            Q_WARN("Failed to update inbox table with a flag marked read");
             break;
         }
 
@@ -991,7 +1051,8 @@ CacheDatabase::getTextsByContact(const QString &strContact)
 
     // We have all the ID's to look for
     if (arrNums.isEmpty ()) {
-        qWarning() << "Not a single ID matched the search string" << strContact;
+        Q_WARN(QString("Not a single ID matched the search string %1")
+               .arg (strContact));
         return rv;
     }
 
@@ -1097,7 +1158,7 @@ CacheDatabase::getProxySettings (bool &bEnable,
         // are other settings, this method will need to change.
         bEnable = bUseSystemProxy = bRequiresAuth = false;
         if (!settings->contains (GV_P_FLAGS)) {
-            qWarning ("Failed to pull the proxy flags from the DB");
+            Q_WARN("Failed to pull the proxy flags from the DB");
             break;
         }
 
@@ -1395,7 +1456,8 @@ CacheDatabase::saveCookies(QList<QNetworkCookie> cookies)
         query.bindValue (":value", value);
         rv = query.exec ();
         if (!rv) {
-            qWarning() << "Failed to insert cookie into DB" << query.lastError();
+            Q_WARN(QString("Failed to insert cookie into DB. %1")
+                   .arg(query.lastError().text()));
             Q_ASSERT(rv);
         }
     }
