@@ -598,44 +598,37 @@ GVApi::onLogin2(bool success, const QByteArray &response, QNetworkReply *reply,
         // There will be 2-3 moved temporarily redirects.
         QUrl urlMoved = NwReqTracker::hasMoved(reply);
         if (!urlMoved.isEmpty ()) {
-            if (urlMoved.toString().contains ("smsAuth", Qt::CaseInsensitive)) {
-                if (emitLog) {
-                    Q_DEBUG("Two factor AUTH required!");
-                }
-                success = beginTwoFactorAuth (urlMoved, token);
-            } else {
-                QString dest = urlMoved.toString ();
-                if (dest.contains ("voice/help/setupMobile")) {
-                    accountConfigured = false;
-                    success = false;
-                    break;
-                }
+            QString dest = urlMoved.toString ();
+            if (dest.contains ("voice/help/setupMobile")) {
+                accountConfigured = false;
+                success = false;
+                break;
+            }
 
-                if (dest.contains ("AccountRecoveryOptions")) {
-                    token->outParams["nextUrl"] = urlMoved;
-                    accountReviewRequested = true;
-                    success = false;
-                    break;
-                }
+            if (dest.contains ("AccountRecoveryOptions")) {
+                token->outParams["nextUrl"] = urlMoved;
+                accountReviewRequested = true;
+                success = false;
+                break;
+            }
 #if 0
-                if (emitLog) {
-                    Q_DEBUG("Moved to") << dest;
-                }
+            if (emitLog) {
+                Q_DEBUG("Moved to") << dest;
+            }
 #endif
 
-                int foreign = 0;
-                if ((token->outParams.contains ("foreign")) &&
-                    ((dest == GV_HTTPS_M) ||
-                      (foreign = token->outParams["foreign"].toInt()) > 0))
-                {
-                    foreign++;
-                    token->outParams["foreign"] = foreign;
-                    success = doGet (urlMoved, token, this,
-                                     SLOT(onLogin2(bool, const QByteArray &,
-                                                   QNetworkReply *, void *)));
-                } else {
-                    success = postLogin (urlMoved, token);
-                }
+            int foreign = 0;
+            if ((token->outParams.contains ("foreign")) &&
+                ((dest == GV_HTTPS_M) ||
+                  (foreign = token->outParams["foreign"].toInt()) > 0))
+            {
+                foreign++;
+                token->outParams["foreign"] = foreign;
+                success = doGet (urlMoved, token, this,
+                                 SLOT(onLogin2(bool, const QByteArray &,
+                                               QNetworkReply *, void *)));
+            } else {
+                success = postLogin (urlMoved, token);
             }
             break;
         }
@@ -646,7 +639,8 @@ GVApi::onLogin2(bool success, const QByteArray &response, QNetworkReply *reply,
                 break;
             }
 
-            QRegExp rxBody("<body>(.*)</body>");
+            QRegExp rxBody("<body.*>(.*)</body>");
+            rxBody.setMinimal(true);
             if (!strResponse.contains (rxBody)) {
                 break;
             }
@@ -662,7 +656,7 @@ GVApi::onLogin2(bool success, const QByteArray &response, QNetworkReply *reply,
             }
 
             QString docElemText = docElem.text ();
-            Q_DEBUG("docElem = ") << docElemText;
+//            Q_DEBUG(docElemText);
 
             if (docElemText.contains ("The username or password you entered "
                                       "is incorrect."))
@@ -671,6 +665,36 @@ GVApi::onLogin2(bool success, const QByteArray &response, QNetworkReply *reply,
                 break;
             }
 
+            bool needsTwoFactor = false;
+            QDomNodeList formList = docElem.elementsByTagName ("form");
+            QDomElement twoFactorForm;
+            if (!formList.isEmpty ()) {
+                for (uint i = 0; i < formList.length (); i++) {
+                    twoFactorForm = formList.at(i).toElement ();
+                    if (twoFactorForm.isNull ()) {
+                        continue;
+                    }
+
+                    QString formId = twoFactorForm.attribute ("id");
+                    if (formId == "verify-form") {
+                        needsTwoFactor = true;
+                        break;
+                    }
+                }
+            }
+
+            if (needsTwoFactor) {
+                if (emitLog) {
+                    Q_DEBUG("Two factor AUTH required!");
+                }
+
+                token->inParams["tfaAction"] = twoFactorForm.attribute("action");
+
+                emit twoStepAuthentication(token);
+                foreignUrl = true;
+                break;
+            }
+
             QDomNodeList aList = docElem.elementsByTagName ("a");
             if (aList.isEmpty ()) {
                 break;
@@ -757,126 +781,62 @@ GVApi::onLogin2(bool success, const QByteArray &response, QNetworkReply *reply,
 }//GVApi::onLogin2
 
 bool
-GVApi::beginTwoFactorAuth(QUrl url, AsyncTaskToken *token)
-{
-    url.addQueryItem("service", "grandcentral");
-
-    bool rv = doGet(url, token, this,
-                    SLOT(onTwoFactorLogin(bool, const QByteArray &,
-                                          QNetworkReply *, void *)));
-    Q_ASSERT(rv);
-
-    return rv;
-}//GVApi::beginTwoFactorAuth
-
-void
-GVApi::onTwoFactorLogin(bool success, const QByteArray &response,
-                        QNetworkReply *reply, void *ctx)
-{
-    AsyncTaskToken *token = (AsyncTaskToken *)ctx;
-    QString strResponse = response;
-
-    do { // Begin cleanup block (not a loop)
-        if (!success) break;
-
-        QUrl urlMoved = NwReqTracker::hasMoved (reply);
-        if (!urlMoved.isEmpty ()) {
-            success = beginTwoFactorAuth (urlMoved, token);
-            break;
-        }
-
-        Q_DEBUG(strResponse);
-
-        // After which we should have completed login. Check for cookie "gvx"
-        success = false;
-        foreach (QNetworkCookie gvx, jar->getAllCookies ()) {
-            if (gvx.name () == "gvx") {
-                success = true;
-                break;
-            }
-        }
-
-        if (success) {
-            Q_DEBUG("Login succeeded");
-            token->status = ATTS_SUCCESS;
-            token->emitCompleted ();
-            token = NULL;
-            break;
-        }
-
-        success = doTwoFactorAuth (strResponse, token);
-    } while (0); // End cleanup block (not a loop)
-
-    if (!success) {
-        Q_WARN("Login failed.") << strResponse;
-
-        if (token) {
-            token->status = ATTS_LOGIN_FAILURE;
-            token->emitCompleted ();
-        }
-    }
-}//GVApi::onTwoFactorLogin
-
-bool
-GVApi::doTwoFactorAuth(const QString &strResponse, AsyncTaskToken *token)
+GVApi::resumeTFALogin(AsyncTaskToken *token)
 {
     QNetworkCookie galx;
-    bool foundgalx = false, rv = false;
+    bool foundgalx = false;
+    bool rv = false;
 
     do { // Begin cleanup block (not a loop)
-        foreach (QNetworkCookie cookie, jar->getAllCookies ()) {
-            if (cookie.name () == "GALX") {
-                galx = cookie;
+        QString smsUserPin = token->inParams["user_pin"].toString();
+        if (smsUserPin.isEmpty ()) {
+            Q_WARN("User didn't enter 2-step auth pin");
+            break;
+        }
+
+        QString formAction = token->inParams["tfaAction"].toString();
+        if (formAction.isEmpty ()) {
+            Q_CRIT("Two factor auth cannot continue without the form action");
+            break;
+        }
+
+        foreach (galx, jar->getAllCookies ()) {
+            if (galx.name () == "GALX") {
                 foundgalx = true;
             }
         }
 
-        QVariantMap ret;
-        if (!parseHiddenLoginFields (strResponse, ret)) {
-            break;
-        }
-
-        if (!ret.contains ("smsToken")) {
-            // It isn't two factor authentication
-            Q_WARN("Username or password is incorrect!");
-            break;
-        }
-
         if (!foundgalx) {
-            Q_WARN("Cannot proceed with two factor auth. Giving up");
+            Q_WARN("Required 2 step auth but didn't find GALX");
             break;
         }
 
-        emit twoStepAuthentication(token);
-        if (!token->inParams.contains ("user_pin")) {
-            Q_WARN("User didn't enter user pin");
-            break;
-        }
+        QUrl twoFactorUrl = QUrl::fromPercentEncoding(formAction.toLatin1 ());
 
-        QString smsUserPin = token->inParams["user_pin"].toString();
+        QUrl content = twoFactorUrl;
+        content.addQueryItem("smsUserPin"      , smsUserPin);
+        content.addQueryItem("smsVerifyPin"    , "Verify");
+        content.addQueryItem("PersistentCookie", "yes");
+        content.addQueryItem("GALX"            , galx.value());
 
-        QUrl url(GV_ACCOUNT_SMSAUTH), url1(GV_ACCOUNT_SMSAUTH);
-        url.addQueryItem("service"          , "grandcentral");
-
-        url1.addQueryItem("smsUserPin"      , smsUserPin);
-        url1.addQueryItem("smsVerifyPin"    , "Verify");
-        url1.addQueryItem("PersistentCookie", "yes");
-        url1.addQueryItem("service"         , "grandcentral");
-        url1.addQueryItem("GALX"            , galx.value());
-
-        QStringList keys = ret.keys ();
-        foreach (QString key, keys) {
-            url1.addQueryItem(key, ret[key].toString());
-        }
-
-        rv = doPostForm(url, url1.encodedQuery(), token, this,
-                        SLOT(onTFAAutoPost(bool, const QByteArray &,
-                                           QNetworkReply *, void *)));
+        rv = doPostForm(twoFactorUrl, content.encodedQuery(), token, this,
+              SLOT(onTFAAutoPost(bool,const QByteArray&,QNetworkReply*,void*)));
         Q_ASSERT(rv);
     } while (0); // End cleanup block (not a loop)
 
-    return (rv);
-}//GVApi::doTwoFactorAuth
+    if (!rv) {
+        Q_WARN("Two factor authentication failed.");
+
+        if (token->errorString.isEmpty()) {
+            token->errorString = tr("The username or password you entered "
+                                    "is incorrect.");
+        }
+        token->status = ATTS_LOGIN_FAILURE;
+        token->emitCompleted ();
+    }
+
+    return (true);
+}//GVApi::resumeTFALogin
 
 void
 GVApi::onTFAAutoPost(bool success, const QByteArray &response,
