@@ -55,6 +55,7 @@ public:
 ////////////////////////////////////////////////////////////////////////////////
 // GV API:
     bool login(AsyncTaskToken *token);
+    bool resumeTFALogin(AsyncTaskToken *token);
     bool logout(AsyncTaskToken *token);
     bool getPhones(AsyncTaskToken *token);
     bool getInbox(AsyncTaskToken *token);
@@ -83,13 +84,13 @@ private slots:
                   QNetworkReply *reply, void *ctx);
     void onLogin2(bool success, const QByteArray &response,
                   QNetworkReply *reply, void *ctx);
-    void onTwoFactorLogin(bool success, const QByteArray &response,
-                          QNetworkReply *reply, void *ctx);
     void onTFAAutoPost(bool success, const QByteArray &response,
                        QNetworkReply *reply, void *ctx);
     void onGotRnr(bool success, const QByteArray &response,
                   QNetworkReply *reply, void *ctx);
 
+    void internalLogoutForReLogin(AsyncTaskToken *token);
+
     // Logout
     void onLogout(bool success, const QByteArray &response,
                   QNetworkReply *reply, void *ctx);
@@ -141,8 +142,6 @@ private:
     bool doLogin1(QUrl url, AsyncTaskToken *token);
     bool postLogin(QUrl url, AsyncTaskToken *token);
     bool parseHiddenLoginFields(const QString &strResponse, QVariantMap &ret);
-    bool beginTwoFactorAuth(QUrl url, AsyncTaskToken *token);
-    bool doTwoFactorAuth(const QString &strResponse, AsyncTaskToken *token);
     bool getRnr(AsyncTaskToken *token);
 
     // Send SMS
@@ -167,6 +166,8 @@ private:
     QVariantMap hiddenLoginFields;
 
     bool dbgAlwaysFailDialing;
+
+    QScriptEngine scriptEngine;
 };
 
 #endif // GVAPI_H
