@@ -154,7 +154,7 @@ MainWindow::~MainWindow ()
         oInbox = NULL;
     }
 
-    Singletons::getRef().deinit ();
+    Singletons::getRef().deinit();
 }//MainWindow::~MainWindow
 
 /** Invoked when the QtSingleApplication sends a message
@@ -259,9 +259,9 @@ MainWindow::init ()
              this , SLOT(onSigGvApiProgress(double)));
     Q_ASSERT(rv);
 
-/*
-    rv = connect ( this       , SIGNAL (dialCanFinish ()),
-                      &webPage    , SLOT   (dialCanFinish ()));
+/* In case I *ever* think of going back to the webPage way of doing things...
+    rv = connect (this    , SIGNAL(dialCanFinish()),
+                  &webPage, SLOT  (dialCanFinish()));
     Q_ASSERT(rv);
     if (!rv) { exit(1); }
 */
@@ -511,10 +511,6 @@ MainWindow::initQML ()
                   this, SLOT(on_actionE_xit_triggered ()));
     Q_ASSERT(rv);
     if (!rv) { exit(1); }
-    rv = connect (gObj, SIGNAL(sigMsgBoxDone(bool)),
-                  this, SLOT(onSigMsgBoxDone(bool)));
-    Q_ASSERT(rv);
-    if (!rv) { exit(1); }
     rv = connect (
         gObj     , SIGNAL(sigSearchContacts(const QString &)),
         oContacts, SLOT(onSearchQueryChanged(const QString &)));
@@ -555,6 +551,14 @@ MainWindow::initQML ()
     Q_ASSERT(rv);
     if (!rv) { exit(1); }
 
+    gObj = getQMLObject ("MsgBox");
+    rv = connect (gObj, SIGNAL(sigOk()), this, SLOT(onSigMsgBoxOk()));
+    Q_ASSERT(rv);
+    if (!rv) { exit(1); }
+    rv = connect (gObj, SIGNAL(sigCancel()), this, SLOT(onSigMsgBoxCancel()));
+    Q_ASSERT(rv);
+    if (!rv) { exit(1); }
+
     // Now do the settings page
     if (!connectSettingsSignals ()) {
         exit (1);
@@ -718,9 +722,9 @@ MainWindow::getContactsDone (bool bOk)
 }//MainWindow::getContactsDone
 
 void
-MainWindow::initContacts ()
+MainWindow::initContacts (const QString &contactsPass)
 {
-    oContacts->setUserPass (strUser, strPass);
+    oContacts->setUserPass (strUser, contactsPass);
     oContacts->loginSuccess ();
     oContacts->initModel ();
     oContacts->refreshContacts ();
@@ -1062,7 +1066,7 @@ MainWindow::refreshPinSettings()
 }//MainWindow::refreshPinSettings
 
 void
-MainWindow::showMsgBox (const QString &strMessage)
+MainWindow::showMsgBox (const QString &strMessage, bool inputBox)
 {
     QObject *obj = getQMLObject ("MsgBox");
     if (NULL == obj) {
@@ -1071,11 +1075,24 @@ MainWindow::showMsgBox (const QString &strMessage)
     }
 
     obj->setProperty ("msgText", strMessage);
+    obj->setProperty ("inputBox", inputBox);
     obj->setProperty ("opacity", QVariant(1.0));
 }//MainWindow::showMsgBox
 
 void
-MainWindow::onSigMsgBoxDone (bool /*ok = true*/)
+MainWindow::showMsgBox (const QString &strMessage)
+{
+    showMsgBox (strMessage, false);
+}//MainWindow::showMsgBox
+
+void
+MainWindow::showInputBox (const QString &strMessage)
+{
+    showMsgBox (strMessage, true);
+}//MainWindow::showInputBox
+
+void
+MainWindow::onSigMsgBoxDone (bool ok /* = true*/)
 {
     QObject *obj = getQMLObject ("MsgBox");
     if (NULL == obj) {
@@ -1084,8 +1101,22 @@ MainWindow::onSigMsgBoxDone (bool /*ok = true*/)
     }
 
     obj->setProperty ("opacity", QVariant(0.0));
+
+    emit sigMessageBoxDone(ok);
 }//MainWindow::onSigMsgBoxDone
 
+void
+MainWindow::onSigMsgBoxOk()
+{
+    onSigMsgBoxDone(true);
+}//MainWindow::onSigMsgBoxOk
+
+void
+MainWindow::onSigMsgBoxCancel()
+{
+    onSigMsgBoxDone(false);
+}//MainWindow::onSigMsgBoxCancel
+
 void
 MainWindow::onCallInitiatorsChange (bool bSave)
 {
@@ -1249,13 +1280,6 @@ MainWindow::onRecreateCookieJar()
     gvApi.setAllCookies (empty);
 }//MainWindow::onRecreateCookieJar
 
-void
-MainWindow::onTwoStepAuthentication(AsyncTaskToken *token)
-{
-    int rv = QInputDialog::getInt (this, "Enter security token", "Token: ", 0, 0);
-    token->inParams["user_pin"] = QString("%1").arg (rv);
-}//MainWindow::onTwoStepAuthentication
-
 void
 MainWindow::onOrientationChanged(OsIndependentOrientation /*o*/)
 {
